# Generated by Django 3.2.8 on 2021-10-29 03:42

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='AmisRenderList',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('page_url', models.TextField(blank=True, null=True)),
                ('file_path', models.TextField(blank=True, null=True)),
                ('html_template', models.TextField(blank=True, null=True)),
                ('json_file_url', models.TextField(blank=True, null=True)),
                ('file_type', models.TextField(blank=True, help_text='supported file type: json or html', null=True)),
            ],
            options={
                'verbose_name_plural': 'AMIS-PAGE',
                'db_table': 'amis_render_list',
                'managed': True,
            },
        ),
    ]
